<%@ Application Language="C#" %>
<%@ Import Namespace="ChooseYourStory.Legacy" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.Data.SqlClient" %>
<%@ Import Namespace="System.Collections" %>

<script RunAt="server">

    void Application_Error(object sender, EventArgs e)
    {
        Exception ex = Server.GetLastError().GetBaseException();

        if (ex is ChooseYourStory.Stories.Editing.NotAuthorizedToEditException)
        {
            Response.Redirect("/errors/notAuthorizedToEdit.aspx");
        }

        if (ex is HttpException && ex.Message == "Maximum request length exceeded.")
        {
            Response.Redirect(
                Request.Url.ToString() +
                (
                    string.IsNullOrEmpty(Request.Url.Query)
                    ? "?err=tooLarge"
                    : "&err=tooLarge"
                )
            );
        }
    }

    void Application_Start(object sender, EventArgs e)
    {

        DataTable users = new DataTable();
        users.Columns.Add("Username", typeof(string));
        users.Columns.Add("LastActivity", typeof(DateTime));
        users.Columns.Add("LastPage", typeof(string));
        users.PrimaryKey = new DataColumn[] { users.Columns["Username"] };
        Application.Add("UsersOnline", users);

        DataTable sessions = new DataTable();
        sessions.Columns.Add("IP", typeof(string));
        sessions.Columns.Add("LastActivity", typeof(DateTime));
        sessions.PrimaryKey = new DataColumn[] { sessions.Columns["IP"] };
        Application.Add("Sessions", sessions);
    }

    void Application_PostAcquireRequestState(object sender, EventArgs e)
    {
        if (HttpContext.Current.Session != null)
        {
            //synch with ASP pages
            AspSessionBridge.SynchAspSession();

            Application.Lock();

            { //whos online
                DataTable users = (DataTable)Application["UsersOnline"];
                if (User.Identity.IsAuthenticated)
                {
                    DataRow userRow = users.Rows.Find(User.Identity.Name);
                    if (userRow == null)
                    {
                        users.Rows.Add(new object[] { User.Identity.Name, DateTime.Now, Request.Path });
                    }
                    else
                    {
                        userRow["LastActivity"] = DateTime.Now;
                        userRow["LastPage"] = Request.Path;
                    }
                }

                DataRow[] oldRows = users.Select("LastActivity < '" + DateTime.Now.AddMinutes(-5).ToString() + "'");
                foreach (DataRow row in oldRows) users.Rows.Remove(row);
            }

            { //sessions
                DataTable sessions = (DataTable)Application["Sessions"];
                DataRow curr = sessions.Rows.Find(Request.UserHostAddress);
                if (curr == null)
                {
                    sessions.Rows.Add(new object[] { Request.UserHostAddress, DateTime.Now });
                }
                else
                {
                    curr["LastActivity"] = DateTime.Now;
                }

                DataRow[] oldRows = sessions.Select("LastActivity < '" + DateTime.Now.AddMinutes(-5).ToString() + "'");
                foreach (DataRow row in oldRows) sessions.Rows.Remove(row);
            }

            Application.UnLock();

            if (User.Identity.IsAuthenticated)
            {

                var user = (ChooseYourStory.Web.Security.CysMembershipUser)Membership.GetUser();
                if (user.Banned)
                {
                    FormsAuthentication.SignOut();
                    Response.Redirect("/Banned.aspx");
                }

                using (SqlCommand cmd = new SqlCommand())
                {
                    cmd.Connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ChooseYourStory"].ConnectionString);
                    cmd.CommandText = "User_UpdateLastLogon";
                    cmd.CommandType = CommandType.StoredProcedure;
                    cmd.Parameters.Add("@Username", SqlDbType.VarChar, 30).Value = User.Identity.Name;
                    try
                    {
                        cmd.Connection.Open();
                        cmd.ExecuteNonQuery();
                    }
                    finally
                    {
                        cmd.Connection.Close();
                    }
                }

            }
        }
    }

</script>

