<%@ Page Language="C#" AutoEventWireup="true" 
    Title="Storygames" EnableViewState="false" ClassName="ChooseYourStory.Web.UI.Stories.Category" %>
<%@ Register TagPrefix="cys" 
    Namespace="ChooseYourStory.Web.Controls"
    Assembly="ChooseYourStory" %>    
<%@ Import Namespace="System.Data"%>
<%@ Import Namespace="System.Data.SqlClient"%>
<%@ Import Namespace="ChooseYourStory.Utilities"%>
<%@ Import Namespace="ChooseYourStory.Categories"%>
<%@ Import Namespace="ChooseYourStory.Stories.Rating" %>
<script runat="server" language="C#">
    protected DataTable StoriesTable = new DataTable();
    protected int FilteredStoriesCount = 0;
    protected CategoryInfo categoryInfo;
    protected string CategoryName;
    protected string LargeImageUrl;
    protected int PageIndex = 0;

    private void LoadNewStories()
    {
        using (SqlCommand cmd = new SqlCommand())
        {
            cmd.Connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ChooseYourStory"].ConnectionString);

            cmd.CommandText = "Stories_Get_New_Stories";
            cmd.CommandType = CommandType.StoredProcedure;
            cmd.Parameters.Add("@Count", SqlDbType.Int).Value = 20;
            cmd.Parameters.Add("@Username", SqlDbType.VarChar, 30).Value =
                User.Identity.IsAuthenticated ? (object) User.Identity.Name : DBNull.Value;

            try
            {
                cmd.Connection.Open();
                StoriesTable.Load(cmd.ExecuteReader());
            }
            finally
            {
                cmd.Connection.Close();
            }
        }
    }

    private void LoadTopStories()
    {
        using (SqlCommand cmd = new SqlCommand())
        {
            cmd.Connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ChooseYourStory"].ConnectionString);

            cmd.CommandText = "Stories_Get_Top_Stories";
            cmd.CommandType = CommandType.StoredProcedure;
            cmd.Parameters.Add("@Year", SqlDbType.Int).Value = null;
            cmd.Parameters.Add("@Count", SqlDbType.Int).Value = 100;
            cmd.Parameters.Add("@Username", SqlDbType.VarChar, 30).Value =
                User.Identity.IsAuthenticated ? (object)User.Identity.Name : DBNull.Value;

            try
            {
                cmd.Connection.Open();
                StoriesTable.Load(cmd.ExecuteReader());
            }
            finally
            {
                cmd.Connection.Close();
            }
        }
    }

    private void LoadTopStoriesYear(int Year)
    {
        using (SqlCommand cmd = new SqlCommand())
        {
            cmd.Connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ChooseYourStory"].ConnectionString);

            cmd.CommandText = "Stories_Get_Top_Stories";
            cmd.CommandType = CommandType.StoredProcedure;
            cmd.Parameters.Add("@Year", SqlDbType.Int).Value = Year;
            cmd.Parameters.Add("@Count", SqlDbType.Int).Value = 10;
            cmd.Parameters.Add("@Username", SqlDbType.VarChar, 30).Value =
                User.Identity.IsAuthenticated ? (object)User.Identity.Name : DBNull.Value;

            try
            {
                cmd.Connection.Open();
                StoriesTable.Load(cmd.ExecuteReader());
            }
            finally
            {
                cmd.Connection.Close();
            }
        }
    }

    private void LoadStories(string categoryId)
    {
        using (SqlCommand cmd = new SqlCommand())
        {
            cmd.Connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ChooseYourStory"].ConnectionString);

            cmd.CommandText = "Stories_Get_Stories";
            cmd.CommandType = CommandType.StoredProcedure;

            cmd.Parameters.Add("@CategoryId", SqlDbType.VarChar, 20).Value = categoryId;
            cmd.Parameters.Add("@MinimumRating", SqlDbType.Int).Value = Profile.Stories.MinimumRating;

            cmd.Parameters.Add("@MinimumLength", SqlDbType.Int).Value = Profile.Stories.MinimumLength;
            cmd.Parameters.Add("@MaximumLength", SqlDbType.Int).Value = Profile.Stories.MaximumLength;
            cmd.Parameters.Add("@MinimumDifficulty", SqlDbType.Int).Value = Profile.Stories.MinimumDifficulty;
            cmd.Parameters.Add("@MaximumDifficulty", SqlDbType.Int).Value = Profile.Stories.MaximumDifficulty;

            cmd.Parameters.Add("@SortExpression", SqlDbType.VarChar, 50).Value = Profile.Stories.SortExpression;
            cmd.Parameters.Add("@SortDirection", SqlDbType.VarChar, 4).Value = Profile.Stories.SortDirection;

            cmd.Parameters.Add("@Username", SqlDbType.VarChar, 30).Value = User.Identity.IsAuthenticated ? (object) User.Identity.Name : DBNull.Value;

            cmd.Parameters.Add("@FilteredCount", SqlDbType.Int).Direction = ParameterDirection.Output;

            try
            {
                cmd.Connection.Open();
                StoriesTable.Load(cmd.ExecuteReader());
                FilteredStoriesCount = (int)cmd.Parameters["@FilteredCount"].Value;
            }
            finally
            {
                cmd.Connection.Close();
            }
        }
    }

    //Fixing the new storygame casting bug
    private int FormatStorygameRatingsCount(object value)
    {
        if (value.GetType() != typeof(DBNull))
        {
            return Convert.ToInt32(value);
        }
        else
            return 0;
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        //Load the Category
        categoryInfo = CategoryCache.Instance[Request.QueryString["id"] as string];

        //Page Index
        if (!string.IsNullOrEmpty(Request.QueryString["PageIndex"]))
            PageIndex = int.Parse(Request.QueryString["PageIndex"]);

        //Save Filter DropDown Changes
        if (IsPostBack)
        {
            if (!string.IsNullOrEmpty(Request.Form[ddlMinimumRating.UniqueID]))
                Profile.Stories.MinimumRating = Request.Form[ddlMinimumRating.UniqueID];
            if (!string.IsNullOrEmpty(Request.Form[ddlMinimumLength.UniqueID]))
                Profile.Stories.MinimumLength = Request.Form[ddlMinimumLength.UniqueID];
            if (!string.IsNullOrEmpty(Request.Form[ddlMaximumLength.UniqueID]))
                Profile.Stories.MaximumLength = Request.Form[ddlMaximumLength.UniqueID];
            if (!string.IsNullOrEmpty(Request.Form[ddlMinimumDifficulty.UniqueID]))
                Profile.Stories.MinimumDifficulty = Request.Form[ddlMinimumDifficulty.UniqueID];
            if (!string.IsNullOrEmpty(Request.Form[ddlMaximumDifficulty.UniqueID]))
                Profile.Stories.MaximumDifficulty = Request.Form[ddlMaximumDifficulty.UniqueID];

            Profile.Save();
        }

        if (categoryInfo == null)
        {
            CategoryName = Request.QueryString["id"];
        }

        Title = "Storygames > " + ((categoryInfo == null) ?
            (CategoryName == "new" ? "New" : "Top") :
            categoryInfo.Name);
    }


    protected void Page_PreRender(object sender, EventArgs e)
    {
        //Load related stories
        if (categoryInfo == null)
        {
            int catYear;
            if (CategoryName == "top")
            {
                CategoryName = "Top Storygames (Overall)";
                LargeImageUrl = "categories/top_rated_full.gif";
                FilterOptionsPlaceHolder.Visible = false;
                StoriesGridView.AllowSorting = false;
                LoadTopStories();
            }
            else if (int.TryParse(CategoryName, out catYear))
            {
                CategoryName = "Top Storygames of " + CategoryName;
                LargeImageUrl = "categories/top_rated_full.gif";
                FilterOptionsPlaceHolder.Visible = false;
                StoriesGridView.AllowSorting = false;
                LoadTopStoriesYear(catYear);
            }
            else
            {
                CategoryName = "New Storygames";
                LargeImageUrl = "categories/new_full.gif";
                FilterOptionsPlaceHolder.Visible = false;
                StoriesGridView.AllowSorting = false;
                LoadNewStories();
            }
        }
        else
        {
            LoadStories(categoryInfo.CategoryID);
            CategoryName = categoryInfo.Name;
            LargeImageUrl = categoryInfo.LargeImageUrl;
        }

        //Set the grid's page index
        StoriesGridView.PageIndex = PageIndex;

        //finally bind
        DataBind();

        //Querystring
        if (PageIndex > 0) Form.Action = "?PageIndex=" + PageIndex.ToString();
        else Form.Action = "?";

        //Set selected values
        ddlMinimumRating.SelectedValue = Profile.Stories.MinimumRating;
        ddlMinimumLength.SelectedValue = Profile.Stories.MinimumLength;
        ddlMaximumLength.SelectedValue = Profile.Stories.MaximumLength;
        ddlMinimumDifficulty.SelectedValue = Profile.Stories.MinimumDifficulty;
        ddlMaximumDifficulty.SelectedValue = Profile.Stories.MaximumDifficulty;

        //Remove the "0" value
        ddlMinimumRating.Items.RemoveAt(0);
        ddlMinimumLength.Items.RemoveAt(0);
        ddlMaximumLength.Items.RemoveAt(0);
        ddlMinimumDifficulty.Items.RemoveAt(0);
        ddlMaximumDifficulty.Items.RemoveAt(0);
    }

    #region Gridview Handlers
    protected void StoriesGridView_Sorting(Object sender, GridViewSortEventArgs e)
    {
        if (Profile.Stories.SortExpression == e.SortExpression)
        {
            Profile.Stories.SortDirection =
                (Profile.Stories.SortDirection == "ASC") ? "DESC" : "ASC";
        }
        else
        {
            Profile.Stories.SortExpression = e.SortExpression;
            Profile.Stories.SortDirection = "ASC";
        }

        Profile.Save();
    }
    protected void StoriesGridView_PageIndexChanging(Object sender, GridViewPageEventArgs e)
    {
        PageIndex = e.NewPageIndex;
    }
    #endregion
</script>    
<asp:Content runat="server" ContentPlaceHolderID="HeaderContentPlaceHolder">
    <script language="javascript" type="text/javascript">
        function showHideFilterDiv(refLink)
        {
					var refLink = document.getElementById('FilterOptionsDiv_ShowLink');
            
            div = document.getElementById("FilterOptionsDiv");
            if (div.style.display == 'none')
            {
                div.style.display = 'block';
                refLink.style.display = 'none';
            }
            else
            {
                div.style.display = 'none';
                refLink.style.display = 'inline';
            }
        }
    </script>
		<style type="text/css">

		</style>        
	<!--[if IE]>
		<style type="text/css">
			div.iehack { background-attachment: fixed; }
		</style>
	<![endif]--> 
</asp:Content>
<asp:Content ContentPlaceHolderID="MainContentPlaceHolder" Runat="Server">
<cys:Form runat="server" id="Form">
    <div id="mainContent">
      
    <h1><a href="./">Storygames</a> &gt;
        <%# CategoryName %></h1>
        
        <asp:PlaceHolder runat="server" ID="FilterOptionsPlaceHolder">
        <a id="FilterOptionsDiv_ShowLink" href="#" class="smallerText" onclick="showHideFilterDiv(); return false;">[Set Filter Options]</a>
        <div id="FilterOptionsDiv" style="display:none;padding:10px;position:relative;z-index:99;" class="back2Background">
            
            <h2>Filter Options</h2>
            <table>
                <tr>
                    <th>Min. Rating</th>
                    <td><asp:DropDownList runat="server" ID="ddlMinimumRating" 
                            DataSource="<%#ChooseYourStory.Stories.Rating.RatingLevelCache.Instance %>"
                            DataTextField="Description"
                            DataValueField="RatingLevel"
                         /></td>
                    <th>&nbsp;</th>
                    <th>&nbsp;</th>
                </tr>
                <tr>
                    <th>Min. Length</th>
                    <td><asp:DropDownList runat="server" ID="ddlMinimumLength" 
                            DataSource="<%#ChooseYourStory.Stories.Length.LengthLevelCache.Instance %>"
                            DataTextField="Description"
                            DataValueField="LengthLevel"
                         /></td>
                    <th>Max. Length</th>
                    <td><asp:DropDownList runat="server" ID="ddlMaximumLength" 
                            DataSource="<%#ChooseYourStory.Stories.Length.LengthLevelCache.Instance %>"
                            DataTextField="Description"
                            DataValueField="LengthLevel"
                         /></td>
                </tr>
                <tr>
                    <th>Min. Difficulty</th>
                    <td><asp:DropDownList runat="server" ID="ddlMinimumDifficulty" 
                            DataSource="<%#ChooseYourStory.Stories.Difficulty.DifficultyLevelCache.Instance %>"
                            DataTextField="Description"
                            DataValueField="DifficultyLevel"
                         /></td>
                    <th>Max. Difficulty</th>
                    <td><asp:DropDownList runat="server" ID="ddlMaximumDifficulty" 
                            DataSource="<%#ChooseYourStory.Stories.Difficulty.DifficultyLevelCache.Instance %>"
                            DataTextField="Description"
                            DataValueField="DifficultyLevel"
                         /></td>
                </tr>                
            </table>
            
            <asp:Button runat="server" Text="Set Filter" />       
            &nbsp;
            <input type="button" value="Cancel" onclick="showHideFilterDiv(); return false;" />
        </div>
        </asp:PlaceHolder>
        <div id="stories_storylistdiv" class="iehack" style="height:550px; width:700px;background-image: url(../App_Themes/<%#Theme%>/images/<%#LargeImageUrl%>);background-position: top center;background-repeat:no-repeat;">
            <asp:GridView 
                ID="StoriesGridView"  runat="server" DataSource="<%# StoriesTable %>"
                AllowPaging="False" AllowSorting="True" AutoGenerateColumns="False" 
                PageSize="25"
                OnSorting="StoriesGridView_Sorting" 
                OnPageIndexChanging="StoriesGridView_PageIndexChanging"
                BorderWidth="0px" CellPadding="3"
                PagerSettings-Mode="Numeric"
                PagerSettings-Position="TopAndBottom"
                PagerStyle-HorizontalAlign="right"
                PagerSettings-Visible="false"
                Width="680px" GridLines="None"
                HeaderStyle-CssClass="stories_storylistheaders"
            >
                <Columns>
                    <asp:TemplateField HeaderText="Title" SortExpression="Title" 
                            HeaderStyle-HorizontalAlign="Left" ItemStyle-CssClass="dark1borderTop1pxSolid"
                            HeaderStyle-CssClass="inverse1" HeaderStyle-ForeColor="#FFFFFF">
                        <ItemTemplate>
														<cys:ThemedImage runat="server" Src="star.gif" Visible='<%# "Y".Equals(Eval("Featured_Indicator")) %>' Alt="Featured Story" />
                            <asp:HyperLink ID="HyperLink1" runat="server" 
                                Text='<%#Eval("Story_Title")%>' 
                                NavigateUrl='<%# string.Format("~/story/{0}.aspx", ChooseYourStory.Utilities.UrlEncoding.Encode((string)Eval("Story_Title")))  %>' />
                        </ItemTemplate>
                    </asp:TemplateField>
                    <asp:TemplateField HeaderText="Author" SortExpression="Author" 
                            HeaderStyle-HorizontalAlign="Left" ItemStyle-CssClass="dark1borderTop1pxSolid"
                            HeaderStyle-CssClass="inverse1" HeaderStyle-ForeColor="#FFFFFF">
                        <ItemTemplate>
                            <asp:HyperLink runat="server" 
                                Text='<%#Eval("Author_Username") %>'
                                NavigateUrl='<%# string.Format("~/member/?Username={0}", Server.UrlEncode((string)Eval("Author_Username")))  %>' />
                        </ItemTemplate>
                    </asp:TemplateField>
                    <asp:TemplateField HeaderText="Length" SortExpression="Length"
                            HeaderStyle-HorizontalAlign="Center" ItemStyle-CssClass="dark1borderTop1pxSolid"
                            ItemStyle-HorizontalAlign="Center"
                            HeaderStyle-CssClass="inverse1" HeaderStyle-ForeColor="#FFFFFF">                     
                        <ItemTemplate>
                            <cys:LengthLevelImage runat="server" LengthLevel='<%#Eval("Length_Level") %>' />
                        </ItemTemplate>
                    </asp:TemplateField>                                      
                    <asp:TemplateField HeaderText="Difficulty" SortExpression="Difficulty"
                            HeaderStyle-HorizontalAlign="Left" ItemStyle-CssClass="dark1borderTop1pxSolid"
                            ItemStyle-HorizontalAlign="Center"
                            HeaderStyle-CssClass="inverse1" HeaderStyle-ForeColor="#FFFFFF">
                        <ItemTemplate>
                            <cys:DifficultyLevelImage runat="server" DifficultyLevel='<%#Eval("Difficulty_Level") %>' />
                        </ItemTemplate>
                    </asp:TemplateField>  
                    <asp:TemplateField HeaderText="Rating" SortExpression="Rating" 
                            HeaderStyle-HorizontalAlign="Center" ItemStyle-CssClass="dark1borderTop1pxSolid"
                            HeaderStyle-CssClass="inverse1" HeaderStyle-ForeColor="#FFFFFF"
                            ItemStyle-Wrap="false">
                        <ItemTemplate>
                            <p style="color: #990000"><b><%# FormatStorygameRatingsCount(Eval("Rating_Count")) >= 10 ? Eval("Rating_Level") : "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;?" %></b>  
                                <cys:ThemedImage runat="Server"
                                Src="checkmark.gif" Height="14" Width="14"
                                Alt="You've Already Rated This"
                                Visible='<%# Eval("Rated_Indicator").ToString() == "Y" %>'
                                />
                            </p>
                        </ItemTemplate>
                    </asp:TemplateField>
                </Columns>
            </asp:GridView>
            <div style="padding:10px;" runat="server" visible="<%# FilteredStoriesCount > 0 %>">
                <h2 class="alertTextColor">
                    <%# FilteredStoriesCount%> 
                    <asp:Literal runat="server" Text="Storygames" Visible="<%# FilteredStoriesCount > 1 %>" /> 
                    <asp:Literal runat="server" Text="Storygame" Visible="<%# FilteredStoriesCount == 1 %>" /> 
                    Not Shown </h2>
                <div class="smallerText" style="margin-top:0px; width: 400px; margin-left: 8px; ">
                  Storygames with a low rating are automatically filtered from view. To view all
                  storygames,                   use the link near the top of the page to display and change the
                filter options. If you are a registered member, these preferences will be remembered when
                ever you are logged in. 
                </div>
            </div>              
        </div>
      
    </div>
</cys:Form>

<cys:AspPage runat="server" Url="~/Includes/footer.asp" />
</asp:Content>

