<%@ Page Language="C#" EnableViewState="false" Inherits="System.Web.UI.Page" %>
<%@ Import Namespace="ChooseYourStory.Stories" %>
<%@ Import Namespace="ChooseYourStory.Utilities" %>
<%@ Import Namespace="ChooseYourStory.Stories.Rating" %>
<%@ Register Assembly="ChooseYourStory" Namespace="ChooseYourStory.Web.Controls" TagPrefix="cys" %>

<script runat="server">
	StoryState State;
	RatingLevelInfo lastRating;

	
	protected override void OnLoad(EventArgs e)
	{
		//ensure postback
		if (!Request.Form.HasKeys()) throw new Exception("Invalid input.");
		
		//must be, load storystate
		State = StoryState.CreateFromString(Request.Form["SS"]);
		if (User.Identity.IsAuthenticated)
		{
			lastRating = State.GetLastRating(User.Identity.Name);
		}

		DataBind();
	}
	
	protected bool hasCookie()
	{
		HttpCookie cookie = Request.Cookies["rt"];
		if (cookie == null || string.IsNullOrEmpty(cookie.Value)) return false;

		string[] cookieVals = cookie.Value.Split('x');
		foreach (string val in cookieVals)
		{
			if (val == State.StoryId.ToString()) return true;
		}
		return false;
	}
	
	protected void setCookie()
	{
		if (!hasCookie())
		{
			HttpCookie cookie = Request.Cookies["rt"];
			if (cookie == null || string.IsNullOrEmpty(cookie.Value))
			{
				Response.Cookies.Add(new HttpCookie("rt", State.StoryId.ToString()));
			}
			else
			{
				Response.Cookies.Add(new HttpCookie("rt", cookie.Value + "x" + State.StoryId.ToString()));
			}
			Response.Cookies["rt"].Expires = DateTime.Now.AddDays(90);
		}
	}
	
	protected void SelectRating_Click(object sender, EventArgs e)
	{
		int ratingLevel = int.Parse(((LinkButton)sender).CommandArgument);
		string userName = User.Identity.IsAuthenticated ? User.Identity.Name : null;
		bool cookie = hasCookie();
		string ip = Request.UserHostAddress;

		State.AddRating(ratingLevel, userName, cookie, ip);
		setCookie();
		Server.Transfer("comment.aspx");
	}

	protected void SkipRating_Click(object sender, EventArgs e)
	{
		Server.Transfer("comment.aspx");
	}

</script>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head runat="server">
	<title runat="server">
		<%#State.StoryTitle%>
		:: Story Viewer</title>

	<script language="JavaScript1.2" type="text/javascript"><!--
		function getEl(item) {
			if( window.mmIsOpera ) return(document.getElementById(item));
			if (document.all) return(document.all[item]);
			if (document.getElementById) return(document.getElementById(item));
			return(false);
		}		
	//--></script>
</head>
<body>
	<form runat="server">
		<input type="hidden" name="SS" value="<%#State.CreateStoryStateString()%>" />
	
	<!-- BEGIN BANNER -->		
	<asp:PlaceHolder runat="server">
		<table border="0" cellpadding="0" cellspacing="0" width="100%">
			<tr>
				<td width="150"><cys:ThemedImage runat="server" style="opacity: .6; filter: alpha(opacity=60);" src="storyviewer_masthead_logo.gif" width="150" height="20" border="0" alt="" /></td>
				<td width="100%"><cys:ThemedImage runat="server" style="opacity: .6; filter: alpha(opacity=60); width: 100%" src="storyviewer_masthead_background.gif" width="100" height="20" border="0" alt="" /></td>
			</tr>
		</table>
	</asp:PlaceHolder>
	<!--  END BANNER -->
	
	<!--  BEGIN PAGE TITLE -->
	<div class="dark1border" style="text-align: center; margin: 20px 50px 20px 50px;
		padding: 0px 20px 0px 20px; border-top-width: 1px; border-bottom-width: 1px; border-top-style: solid;
		border-bottom-style: solid;">
		<h1>Rate <%#State.StoryTitle%></h1>
	</div>
	<!-- END PAGE TITLE -->
	
	<!-- BEGIN MAIN -->
	<div style="padding:0px 30px 0px 30px">
		
	  <p>So now that you finished <em><%#State.StoryTitle%></em>, how would you rate it? Note that the author
	  will <em>not</em> see your individual rating; you will have a chance to leave a personal
	  comment once you select a rating.</p>
	  <ul><asp:Repeater runat="server" DataSource="<%#RatingLevelCache.Instance%>">
			<ItemTemplate><li runat="server" visible='<%#(int)Eval("RatingLevel") > 0 %>'>
				<asp:LinkButton runat="server"
					Text='<%#Eval("Description") %>'
					OnClick="SelectRating_Click"
					CommandArgument='<%#Eval("RatingLevel") %>' />
			</li></ItemTemplate>
	  </asp:Repeater></ul>
		
	  <p>
	  <asp:PlaceHolder runat="server" Visible="<%# lastRating != null %>">
	  	<%#User.Identity.Name%>, the last time you rated this game, you gave it 
	  	<em><%#lastRating%></em>. Feel free to change your mind or give it the 
	  	same rating. Only your latest rating is counted.
			
	  </asp:PlaceHolder>
	   If you really don't feel like leaving a rating, you can always 
	   <asp:LinkButton runat="server" OnClick="SkipRating_Click">click here to continue</asp:LinkButton> to the comments screen.
	  </p>
	  
	  <p class="smallerText">Not sure what to rate? Check out the tips for 
	  <a target="_blank" href="/help/articles/article.aspx?ArticleId=16">Rating And Leaving Comments</a>.
	  </p>
	</div>
	<!-- END MAIN -->
	</form>
</body>
</html>
