<%@ Page Language="C#" Title="Edit Script" EnableViewState="false" Inherits="System.Web.UI.Page" %>

<%@ Register TagPrefix="cys" Namespace="ChooseYourStory.Web.Controls" Assembly="ChooseYourStory" %>
<%@ Register TagPrefix="adved" Src="SecondaryNavigation.ascx" TagName="SecondaryNavigation" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.Data.SqlClient" %>
<%@ Import Namespace="ChooseYourStory" %>
<%@ Import Namespace="ChooseYourStory.Data" %>
<%@ Import Namespace="ChooseYourStory.Stories.Editing" %>
<%@ Import Namespace="ChooseYourStory.Stories.Scripting" %>
<%@ Import Namespace="ChooseYourStory.Stories.Editing.Advanced" %>
<script runat="server">

    int StoryId;
    string ScriptType;
    int ScriptId;

    protected override void OnLoad(EventArgs e)
    {
        StoryId = int.Parse(Request.QueryString["StoryId"]);
        EditorHelper.ValidateUserToAdvancedEdit(StoryId, User.Identity.Name);

        ScriptType = Request.QueryString["ScriptType"];
        if (ScriptType.StartsWith("Global")) ScriptId = 0;
        else ScriptId = int.Parse(Request.QueryString["ScriptId"]);

        if (Request.QueryString["Delete"] == "Yes")
        {
            SaveScript();
            Response.Redirect("Scripts.aspx?" + StoryId.ToString());
        }

        if (!IsPostBack) ScriptText.Text = LoadScript();

    }

    protected override void OnLoadComplete(EventArgs e)
    {
        DataBind();
    }
    void Validate_OnClick(object sender, EventArgs e)
    {
        ValidateScript();
    }
    void Save_OnClick(object sender, EventArgs e)
    {
        if (ValidateScript())
        {
            SaveScript();
            ClientScript.RegisterClientScriptBlock(typeof(string), "Close", "var win = ( (window.dialogArguments) ? (window.dialogArguments) : (window.opener) ); if (win) win.btn_save_changes.click();window.close();", true);
        }
        else
        {
            ClientScript.RegisterClientScriptBlock(typeof(string), "Alert", "alert('Could not save script due to errors.');", true);
        }
    }
</script>

<script runat="server">
    bool ValidateScript()
    {
        if (string.IsNullOrEmpty(ScriptText.Text)) return true;
        IParser parser = ScriptingHelper.CreateParser();
        try
        {
            parser.ParseScript(ScriptText.Text);
        }
        catch (ParseException pExp)
        {
            ErrorRepeater.DataSource = pExp.ParseErrors;
            ErrorRepeater.DataBind();
            return false;
        }
        return true;
    }

    void SaveScript()
    {
        string scriptText = null;
        byte[] scriptBytes = null;
        if (!string.IsNullOrEmpty(this.ScriptText.Text))
        {
            scriptText = this.ScriptText.Text;
            scriptBytes = ScriptingHelper.CreateParser().ParseScript(scriptText).GetBytes();
        }

        using (SqlCommand cmd = new SqlCommand())
        {
            cmd.Connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ChooseYourStory"].ConnectionString);
            cmd.CommandText = StoredProcedures.Story_Editing_SaveScript;
            cmd.CommandType = CommandType.StoredProcedure;
            cmd.Parameters.Add("@Story_Id", SqlDbType.Int).Value = StoryId;
            cmd.Parameters.Add("@ScriptType_Name", SqlDbType.VarChar, 10).Value = ScriptType;
            cmd.Parameters.Add("@ScriptType_Id", SqlDbType.Int).Value = ScriptId;
            cmd.Parameters.Add("@Script_Text", SqlDbType.Text).Value = scriptText == null ? DBNull.Value : (object)scriptText;
            cmd.Parameters.Add("@Compiled_Script_Bytes", SqlDbType.Image).Value = scriptBytes == null ? DBNull.Value : (object)scriptBytes;
            try
            {
                cmd.Connection.Open();
                cmd.ExecuteNonQuery();
            }
            finally
            {
                cmd.Connection.Close();
            }
        }
    }

    string LoadScript()
    {
        string scriptText = string.Empty;
        using (SqlCommand cmd = new SqlCommand())
        {
            cmd.Connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ChooseYourStory"].ConnectionString);
            cmd.CommandText = StoredProcedures.Story_Viewer_GetScript;
            cmd.CommandType = CommandType.StoredProcedure;
            cmd.Parameters.Add("@Story_Id", SqlDbType.Int).Value = StoryId;
            cmd.Parameters.Add("@ScriptType_Name", SqlDbType.VarChar, 10).Value = ScriptType;
            cmd.Parameters.Add("@ScriptType_Id", SqlDbType.Int).Value = ScriptId;

            SqlDataReader dr = null;
            try
            {
                cmd.Connection.Open();
                dr = cmd.ExecuteReader(CommandBehavior.SingleRow);
                if (dr.Read())
                {
                    if (dr["Script_Text"] != DBNull.Value) scriptText = (string)dr["Script_Text"];

                    litScriptDesc.Text = "";
                    if (!Convert.IsDBNull(dr["Page_Title_Text"]))
                        litScriptDesc.Text += dr["Page_Title_Text"].ToString();
                    if (!Convert.IsDBNull(dr["Link_Title_Text"]))
                        litScriptDesc.Text += " - " + dr["Link_Title_Text"].ToString();
                }
            }
            finally
            {
                if (dr != null) dr.Close();
                cmd.Connection.Close();
            }
        }
        return scriptText;
    }
</script>

<html xmlns="http://www.w3.org/1999/xhtml">
<head runat="server">
    <title>Edit Script</title>
    <base target="CYS_EditScript" />
    <script type="text/javascript">
        window.name = "CYS_EditScript";

        function initPosition(textBox) {
            if (!textBox.createTextRange) return;
            var storedValue = textBox.value;
            textBox.value = "";
            textBox.select();

            var caretPos = document.selection.createRange();
            textBox.__boundingTop = caretPos.boundingTop;
            textBox.__boundingLeft = caretPos.boundingLeft;

            textBox.value = " ";
            textBox.select();

            caretPos = document.selection.createRange();
            textBox.__boundingWidth = caretPos.boundingWidth;
            textBox.__boundingHeight = caretPos.boundingHeight;

            textBox.value = storedValue;
        }

        function storePosition(textBox) {
            var caretPos = document.selection.createRange();

            var boundingTop = (caretPos.offsetTop + textBox.scrollTop) - textBox.__boundingTop;
            var boundingLeft = (caretPos.offsetLeft + textBox.scrollLeft) - textBox.__boundingLeft;

            textBox.__Line = (boundingTop / textBox.__boundingHeight) + 1;
            textBox.__Column = (boundingLeft / textBox.__boundingWidth) + 1;
        }

        function updatePosition(textBox) {
            if (!textBox.createTextRange) return;
            storePosition(textBox);
            document.getElementById("statusBar").innerHTML = "Line " + textBox.__Line + ", Column " + textBox.__Column;
        }
	</script>
</head>
<body style="padding: 20px;" onload="initPosition(document.getElementById('<%#ScriptText.ClientID %>'))">
    <form runat="server" id="mainForm">
        <table border="0" cellpadding="0" cellspacing="0" width="100%">
            <tr>
                <td>
                    <h2>Edit Script</h2>
                    <div class="smallerText">
                        <asp:Literal runat="Server" ID="litScriptDesc" /></div>
                </td>
                <td align="right" class="smallerText"><a href="#">Help On Scripting</a></td>
            </tr>
        </table>
        <asp:TextBox runat="server" ID="ScriptText" TextMode="MultiLine" Width="100%" Rows="10" Style="font-size: 12px;"
            onmouseup="updatePosition(this)"
            onmousedown="updatePosition(this)"
            onkeyup="updatePosition(this)"
            onkeydown="updatePosition(this)"
            onfocus="updatePosition(this)" />
        <table border="0" cellpadding="0" cellspacing="0" width="100%" style="margin-top: 10px;">
            <tr>
                <td>
                    <asp:Button runat="server" Text="Save Script" OnClick="Save_OnClick" />
                    &nbsp;

                    <asp:Button runat="server" Text="Validate" OnClick="Validate_OnClick" />
                </td>
                <td class="error" align="right">
                    <asp:Repeater runat="server" ID="ErrorRepeater">
                        <ItemTemplate>
                            <img alt="" src="images/exclaim.gif" />
                            <%#Eval("Message")%>
                            <%# 0.Equals(Eval("LineNumber")) ? "" : "Line=" + ((int)Eval("LineNumber")+1).ToString() %>
                            <%# 0.Equals(Eval("ColumnNumber")) ? "" : "Col=" + ((int)Eval("ColumnNumber")+1).ToString()%>
                            <br />
                            <br />
                        </ItemTemplate>
                    </asp:Repeater>
                </td>
            </tr>
        </table>
        <div style="position: absolute; bottom: 5px; font-weight: bold" class="smallerText" id="statusBar"></div>
    </form>
</body>
</html>
